package com.ruoyi.ems.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.ems.domain.PvSupplyH;
import org.apache.ibatis.annotations.Param;

/**
 * 光伏并网计量光伏并网计量-小时Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-02
 */
public interface PvSupplyHMapper
{
    /**
     * 查询光伏并网计量光伏并网计量-小时
     *
     * @param id 光伏并网计量光伏并网计量-小时主键
     * @return 光伏并网计量光伏并网计量-小时
     */
     PvSupplyH selectPvSupplyHById(Long id);

    /**
     * 查询光伏并网计量光伏并网计量-小时列表
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 光伏并网计量光伏并网计量-小时集合
     */
     List<PvSupplyH> selectPvSupplyHList(PvSupplyH pvSupplyH);

     List<PvSupplyH> selectAreaSupplyH(PvSupplyH pvSupplyH);


    List<Map<String,Object>> selectAreaSupplyByDate(@Param("areaCode")String areaCode, @Param("date")String date);

    List<Map<String,Object>> selectAreaSupplyByThisYear(@Param("areaCode")String areaCode, @Param("date")String date);

    List<Map<String,Object>> selectAreaSupplyByMonth(@Param("areaCode")String areaCode, @Param("date")String date);

    /**
     * 新增光伏并网计量光伏并网计量-小时
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 结果
     */
     int insertPvSupplyH(PvSupplyH pvSupplyH);

    /**
     * 修改光伏并网计量光伏并网计量-小时
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 结果
     */
     int updatePvSupplyH(PvSupplyH pvSupplyH);

    /**
     * 删除光伏并网计量光伏并网计量-小时
     *
     * @param id 光伏并网计量光伏并网计量-小时主键
     * @return 结果
     */
     int deletePvSupplyHById(Long id);

    /**
     * 批量删除光伏并网计量光伏并网计量-小时
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deletePvSupplyHByIds(Long[] ids);
}
